package net.wanji.opt.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.bo.CrossIdAndStartEndDateBO;
import net.wanji.opt.bo.AbnormalDetailBO;
import net.wanji.opt.service.impl.SceneEvaluateServiceImpl;
import net.wanji.opt.vo.SceneEvaluateAbnormalDetailVO;
import net.wanji.opt.vo.SceneEvaluateAbnormalDistributeVO;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.text.ParseException;

/**
 * 场景评价
 *
 * @author Kent HAN
 */
@Api(value = "SceneEvaluateController", description = "场景评价")
@RequestMapping("/sceneEvaluate")
@RestController
public class SceneEvaluateController {

    private final SceneEvaluateServiceImpl sceneEvaluateService;

    public SceneEvaluateController(SceneEvaluateServiceImpl sceneEvaluateService) {
        this.sceneEvaluateService = sceneEvaluateService;
    }

    @ApiOperation(value = "异常事件时空分布", notes = "异常事件时空分布", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/abnormalDistribute",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SceneEvaluateAbnormalDistributeVO.class),
    })
    public JsonViewObject abnormalDistribute(@RequestBody CrossIdAndStartEndDateBO bo) {
        SceneEvaluateAbnormalDistributeVO res = sceneEvaluateService.abnormalDistribute(bo);
        return JsonViewObject.newInstance().success(res);
    }

    @ApiOperation(value = "异常事件详情", notes = "异常事件详情", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/abnormalDetail",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SceneEvaluateAbnormalDetailVO.class),
    })
    public JsonViewObject abnormalDetail(@RequestBody AbnormalDetailBO abnormalDetailBO) throws ParseException {
        SceneEvaluateAbnormalDetailVO res = sceneEvaluateService.abnormalDetail(abnormalDetailBO);
        return JsonViewObject.newInstance().success(res);
    }
}